@@ -2,6 +2,7 @@
  *  this file is part of evince, a gnome document viewer
  *
  * Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
+ * Copyright © 2012 Christian Persch
  *
  * Evince is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -36,31 +37,30 @@
 #include <windows.h>
 #endif
 
-static gboolean      unlink_temp_file = FALSE;
-static const gchar  *print_settings;
-static const gchar **filenames;
+static gboolean unlink_temp_file = FALSE;
+static gchar *print_settings = NULL;
+static EvPreviewerWindow *window = NULL;
 
 static const GOptionEntry goption_options[] = {
 	{ "unlink-tempfile", 'u', 0, G_OPTION_ARG_NONE, &unlink_temp_file, N_("Delete the temporary file"), NULL },
 	{ "print-settings", 'p', 0, G_OPTION_ARG_FILENAME, &print_settings, N_("Print settings file"), N_("FILE") },
-	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, NULL, N_("FILE") },
 	{ NULL }
 };
 
 static void
 ev_previewer_unlink_tempfile (const gchar *filename)
 {
-	GFile *file, *tempdir;
+        GFile *file, *tempdir;
 
-	file = g_file_new_for_path (filename);
-	tempdir = g_file_new_for_path (g_get_tmp_dir ());
+        file = g_file_new_for_path (filename);
+        tempdir = g_file_new_for_path (g_get_tmp_dir ());
 
-	if (g_file_has_prefix (file, tempdir)) {
-		g_file_delete (file, NULL, NULL);
-	}
+        if (g_file_has_prefix (file, tempdir)) {
+                g_file_delete (file, NULL, NULL);
+        }
 
-	g_object_unref (file);
-	g_object_unref (tempdir);
+        g_object_unref (file);
+        g_object_unref (tempdir);
 }
 
 static void
@@ -68,9 +68,7 @@ ev_previewer_load_job_finished (EvJob           *job,
 				EvDocumentModel *model)
 {
 	if (ev_job_is_failed (job)) {
-		g_warning ("%s", job->error->message);
 		g_object_unref (job);
-
 		return;
 	}
 	ev_document_model_set_document (model, job->document);
@@ -78,16 +76,13 @@ ev_previewer_load_job_finished (EvJob           *job,
 }
 
 static void
-ev_previewer_load_document (const gchar     *filename,
+ev_previewer_load_document (GFile           *file,
 			    EvDocumentModel *model)
 {
 	EvJob *job;
 	gchar *uri;
-	GFile  *file;
 
-	file = g_file_new_for_commandline_arg (filename);
 	uri = g_file_get_uri (file);
-	g_object_unref (file);
 
 	job = ev_job_load_new (uri);
 	g_signal_connect (job, "finished",
@@ -97,14 +92,54 @@ ev_previewer_load_document (const gchar     *filename,
 	g_free (uri);
 }
 
+static void
+activate_cb (GApplication *application,
+             gpointer user_data)
+{
+        if (window) {
+                gtk_window_present (GTK_WINDOW (window));
+        }
+}
+
+static void
+open_cb (GApplication *application,
+         GFile **files,
+         gint n_files,
+         const gchar *hint,
+         gpointer user_data)
+{
+        EvDocumentModel *model;
+        GFile           *file;
+        char            *path;
+
+        if (n_files != 1) {
+                g_application_quit (application);
+                return;
+        }
+
+        file = files[0];
+
+        model = ev_document_model_new ();
+        ev_previewer_load_document (file, model);
+
+        window = ev_previewer_window_new (model);
+        g_object_unref (model);
+
+        ev_previewer_window_set_print_settings (EV_PREVIEWER_WINDOW (window), print_settings);
+        path = g_file_get_path (file);
+        ev_previewer_window_set_source_file (EV_PREVIEWER_WINDOW (window), path);
+        g_free (path);
+
+        gtk_window_present (GTK_WINDOW (window));
+}
+
 gint
 main (gint argc, gchar **argv)
 {
-	GtkWidget       *window;
+        GtkApplication  *application;
 	GOptionContext  *context;
-	const gchar     *filename;
-	EvDocumentModel *model;
 	GError          *error = NULL;
+        int              status = 1;
 
 #ifdef G_OS_WIN32
     if (fileno (stdout) != -1 &&
@@ -136,66 +171,57 @@ main (gint argc, gchar **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 #endif
-	
+
 	context = g_option_context_new (_("GNOME Document Previewer"));
 	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (context, goption_options, GETTEXT_PACKAGE);
 
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	
+
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
-		g_warning ("Error parsing command line arguments: %s", error->message);
+		g_printerr ("Error parsing command line arguments: %s\n", error->message);
 		g_error_free (error);
 		g_option_context_free (context);
-
-		return 1;
+                return 1;
 	}
 	g_option_context_free (context);
 
-	if (!filenames) {
-		g_warning ("File argument is required");
-		
-		return 1;
-	}
+	if (argc < 2) {
+		g_printerr ("File argument is required\n");
+                return 1;
+	} else if (argc > 2) {
+                g_printerr ("Too many files\n");
+                return 1;
+        }
 
-	filename = filenames[0];
-	
-	if (!g_file_test (filename, G_FILE_TEST_IS_REGULAR)) {
-		g_warning ("Filename \"%s\" does not exist or is not a regular file", filename);
-
-		return 1;
+	if (!g_file_test (argv[1], G_FILE_TEST_IS_REGULAR)) {
+		g_printerr ("Filename \"%s\" does not exist or is not a regular file\n", argv[1]);
+                return 1;
 	}
 
 	if (!ev_init ())
-		return 1;
+                return 1;
 
 	ev_stock_icons_init ();
 
 	g_set_application_name (_("GNOME Document Previewer"));
 	gtk_window_set_default_icon_name ("evince");
 
-	model = ev_document_model_new ();
-	window = ev_previewer_window_new (model);
-	ev_previewer_window_set_source_file (EV_PREVIEWER_WINDOW (window), filename);
-	ev_previewer_window_set_print_settings (EV_PREVIEWER_WINDOW (window), print_settings);
-	g_signal_connect (window, "delete-event",
-			  G_CALLBACK (gtk_main_quit), NULL);
-	g_signal_connect (window, "destroy",
-			  G_CALLBACK (gtk_main_quit), NULL);
-	gtk_widget_show (window);
+        application = gtk_application_new (NULL,
+                                           G_APPLICATION_NON_UNIQUE |
+                                           G_APPLICATION_HANDLES_OPEN);
+        g_signal_connect (application, "activate", G_CALLBACK (activate_cb), NULL);
+        g_signal_connect (application, "open", G_CALLBACK (open_cb), NULL);
 
-	ev_previewer_load_document (filename, model);
-	
-	gtk_main ();
+        status = g_application_run (G_APPLICATION (application), argc, argv);
 
-	if (unlink_temp_file)
-		ev_previewer_unlink_tempfile (filename);
-	if (print_settings)
-		ev_previewer_unlink_tempfile (print_settings);
+        if (unlink_temp_file)
+                ev_previewer_unlink_tempfile (argv[1]);
+        if (print_settings)
+                ev_previewer_unlink_tempfile (print_settings);
 
 	ev_shutdown ();
 	ev_stock_icons_shutdown ();
-	g_object_unref (model);
-	
-	return 0;
+
+	return status;
 }
